ScreenInformation class
Constructors
- ScreenInformation({required Orientation orientation, required DeviceScreenType deviceType, required Size screenSize, required Size localWidgetSize})
Properties
- deviceType → DeviceScreenType
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- localWidgetSize → Size
-
final
- orientation → Orientation
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenSize → Size
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited